@@ -26,7 +26,7 @@ fit.GLMMadaptive <- function (p,formula) {
 		random <- mkForm(as.character(bars))
 	}
 	progress(p,'Fitting via mixed_model: ',fixed,', random=',random)
-	patch.GLMMadaptive(p,GLMMadaptive::mixed_model,c(list(fixed=fixed,random=random,data=p$data,family=p$family),p$dots))
+	patch.GLMMadaptive(p,GLMMadaptive::mixed_model,c(list(fixed=fixed,random=random,data=p$data,family=p$family),p$args))
 }
 
 fit.bam <- function (p,formula) {
@@ -43,55 +43,55 @@ fit.bam <- function (p,formula) {
 		method <- 'fREML'
 	} else {
 		method <- 'ML'
-		p$dots$discrete <- FALSE
+		p$args$discrete <- FALSE
 	}
 	progress(p,'Fitting via bam, with ',method,': ',formula)
-	patch.lm(p,mgcv::bam,c(list(formula=formula,family=p$family,data=p$data,method=method),p$dots))
+	patch.lm(p,mgcv::bam,c(list(formula=formula,family=p$family,data=p$data,method=method),p$args))
 }
 
 fit.buildmer <- function (p,formula) {
 	reml <- p$reml && p$is.gaussian
 	if (is.null(lme4::findbars(formula))) {
-		p$dots$control <- NULL
+		p$args$control <- NULL
 		if (reml) {
 			# gls has issues with weights
-			p$dots <- p$dots[names(p$dots) %in% c('weights','subset','na.action','offset')]
+			p$args <- p$args[names(p$args) %in% c('weights','subset','na.action','offset')]
 			return(fit.gam(p,formula))
 		}
 		if (p$is.gaussian) {
-			p$dots <- p$dots[names(p$dots) %in% names(formals(stats::lm))]
+			p$args <- p$args[names(p$args) %in% names(formals(stats::lm))]
 			progress(p,'Fitting via lm: ',formula)
-			patch.lm(p,stats::lm,c(list(formula=formula,data=p$data),p$dots))
+			patch.lm(p,stats::lm,c(list(formula=formula,data=p$data),p$args))
 		} else {
-			p$dots <- p$dots[names(p$dots) %in% names(formals(stats::glm))]
+			p$args <- p$args[names(p$args) %in% names(formals(stats::glm))]
 			progress(p,'Fitting via glm: ',formula)
-			patch.lm(p,stats::glm,c(list(formula=formula,family=p$family,data=p$data),p$dots))
+			patch.lm(p,stats::glm,c(list(formula=formula,family=p$family,data=p$data),p$args))
 		}
 	} else {
 		if (p$is.gaussian) {
 			progress(p,'Fitting via lmer, with ',ifelse(reml,'REML','ML'),': ',formula)
-			patch.lmer(p,lme4::lmer,c(list(formula=formula,data=p$data,REML=reml),p$dots))
+			patch.lmer(p,lme4::lmer,c(list(formula=formula,data=p$data,REML=reml),p$args))
 		} else {
 			progress(p,'Fitting via glmer, with ',ifelse(reml,'REML','ML'),': ',formula)
-			patch.lmer(p,lme4::glmer,c(list(formula=formula,data=p$data,family=p$family),p$dots))
+			patch.lmer(p,lme4::glmer,c(list(formula=formula,data=p$data,family=p$family),p$args))
 		}
 	}
 }
 
 fit.clmm <- function (p,formula) {
-	clm.control <- p$dots$clm.control
-	clmm.control <- p$dots$clmm.control
-	p$dots$clm.control <- p$dots$clmm.control <- NULL
+	clm.control <- p$args$clm.control
+	clmm.control <- p$args$clmm.control
+	p$args$clm.control <- p$args$clmm.control <- NULL
 	if (is.null(lme4::findbars(formula))) {
-		p$dots <- p$dots[names(p$dots) %in% names(formals(ordinal::clm))]
-		p$dots$control <- clm.control
+		p$args <- p$args[names(p$args) %in% names(formals(ordinal::clm))]
+		p$args$control <- clm.control
 		p$control.name <- p$control.names$clm
-		patch.lm(p,ordinal::clm,c(list(formula=formula,data=p$data),p$dots))
+		patch.lm(p,ordinal::clm,c(list(formula=formula,data=p$data),p$args))
 	} else {
-		p$dots <- p$dots[names(p$dots) %in% names(formals(ordinal::clmm))]
-		p$dots$control <- clmm.control
+		p$args <- p$args[names(p$args) %in% names(formals(ordinal::clmm))]
+		p$args$control <- clmm.control
 		p$control.name <- p$control.names$clmm
-		patch.lm(p,ordinal::clmm,c(list(formula=formula,data=p$data),p$dots))
+		patch.lm(p,ordinal::clmm,c(list(formula=formula,data=p$data),p$args))
 	}
 }
 
@@ -107,8 +107,8 @@ fit.gam <- function (p,formula) {
 	if (p$quickstart > 0) {
 		data <- p$data
 		method <- if (p$reml || p$quickstart > 1) 'fREML' else 'ML'
-		dots <- p$dots[names(p$dots) %in% names(formals(mgcv::bam))]
-		if (method == 'fREML' && p$quickstart > 2 && !'discrete' %in% names(dots)) dots$discrete <- TRUE
+		args <- p$args[names(p$args) %in% names(formals(mgcv::bam))]
+		if (method == 'fREML' && p$quickstart > 2 && !'discrete' %in% names(args)) args$discrete <- TRUE
 		if (p$quickstart > 3) {
 			samfrac <- p$quickstart - floor(p$quickstart)
 			if (samfrac == 0) samfrac <- .1
@@ -116,33 +116,33 @@ fit.gam <- function (p,formula) {
 			data <- data[sample.int(n,n*samfrac),]
 		}
 		if (p$quickstart > 4) {
-			dots$control <- c(p$dots$control,list(epsilon=.02))
+			args$control <- c(p$args$control,list(epsilon=.02))
 		}
 		progress(p,'Quickstart fit with bam/',method,': ',formula)
-		qs <- patch.lm(p,mgcv::bam,c(list(formula=formula,family=p$family,data=data,method=method),dots))
+		qs <- patch.lm(p,mgcv::bam,c(list(formula=formula,family=p$family,data=data,method=method),args))
 		if (!inherits(qs,'try-error')) {
-			p$dots$in.out <- list(sp=unname(qs$sp),scale=qs$sig2)
+			p$args$in.out <- list(sp=unname(qs$sp),scale=qs$sig2)
 			if (startsWith(qs$family$family,'Scaled t')) {
 				if (utils::packageVersion('mgcv') < '1.8.32') {
-					progress(p,paste0('Starting values: ',paste0(p$dots$in.out$sp,collapse=' '),', excluding scaled-t theta values as mgcv version < 1.8.32'))
+					progress(p,paste0('Starting values: ',paste0(p$args$in.out$sp,collapse=' '),', excluding scaled-t theta values as mgcv version < 1.8.32'))
 				} else {
 					# set up starting values for theta
 					th.notrans <- qs$family$getTheta(FALSE)
 					th.trans   <- qs$family$getTheta(TRUE)
 					# transformation undoes the logarithm and then adds min.df to the df, so:
 					min.df <- th.trans[1] - exp(th.notrans[1])
-					progress(p,paste0('Starting values: ',paste0(p$dots$in.out$sp,collapse=' '),' with theta values ',paste0(th.trans,collapse=' '),' and min.df ',min.df))
+					progress(p,paste0('Starting values: ',paste0(p$args$in.out$sp,collapse=' '),' with theta values ',paste0(th.trans,collapse=' '),' and min.df ',min.df))
 					p$family <- mgcv::scat(theta=-th.trans,link=qs$family$link,min.df=min.df)
 				}
 			} else {
-				progress(p,paste0('Starting values: ',paste0(p$dots$in.out$sp,collapse=' '),' with scale parameter ',p$dots$in.out$scale))
+				progress(p,paste0('Starting values: ',paste0(p$args$in.out$sp,collapse=' '),' with scale parameter ',p$args$in.out$scale))
 			}
 		}
 	}
 	method <- if (p$reml) 'REML' else 'ML'
-	p$dots <- p$dots[names(p$dots) %in% names(formals(mgcv::gam))]
+	p$args <- p$args[names(p$args) %in% names(formals(mgcv::gam))]
 	progress(p,'Fitting via gam, with ',method,': ',formula)
-	patch.lm(p,mgcv::gam,c(list(formula=formula,family=p$family,data=p$data,method=method),p$dots))
+	patch.lm(p,mgcv::gam,c(list(formula=formula,family=p$family,data=p$data,method=method),p$args))
 }
 
 fit.gamm <- function (p,formula) {
@@ -150,7 +150,7 @@ fit.gamm <- function (p,formula) {
 	bars <- lme4::findbars(formula)
 	if (is.null(bars)) {
 		if (!has.smooth.terms(formula)) {
-			p$dots <- p$dots[names(p$dots) %in% names(formals(mgcv::gam))]
+			p$args <- p$args[names(p$args) %in% names(formals(mgcv::gam))]
 			p$quickstart <- 0
 			return(fit.gam(p,formula))
 		}
@@ -161,7 +161,7 @@ fit.gamm <- function (p,formula) {
 	}
 	method <- if (p$reml) 'REML' else 'ML'
 	progress(p,'Fitting via gamm, with ',method,': ',fixed,', random=',random)
-	m <- patch.lm(p,mgcv::gamm,c(list(formula=fixed,random=random,family=p$family,data=p$data,method=method),p$dots))
+	m <- patch.lm(p,mgcv::gamm,c(list(formula=fixed,random=random,family=p$family,data=p$data,method=method),p$args))
 	if (inherits(m,'try-error') || p$finalize) m else m$lme
 }
 
@@ -172,7 +172,7 @@ fit.gamm4 <- function (p,formula) {
 	random <- if (length(bars)) mkForm(paste('(',sapply(bars,function (x) as.character(list(x))),')',collapse=' + ')) else NULL
 	if (is.null(random) && !has.smooth.terms(formula)) return(fit.buildmer(p,formula))
 	progress(p,'Fitting via gamm4, with ',ifelse(reml,'REML','ML'),': ',fixed,', random=',random)
-	model <- patch.gamm4(p,gamm4::gamm4,c(list(formula=fixed,random=random,family=p$family,data=p$data,REML=reml),p$dots))
+	model <- patch.gamm4(p,gamm4::gamm4,c(list(formula=fixed,random=random,family=p$family,data=p$data,REML=reml),p$args))
 	if (inherits(model,'try-error') || p$finalize) model else model$mer
 }
 
@@ -183,21 +183,21 @@ fit.glmmTMB <- function (p,formula) {
 		if (is.character(family)) family <- get(family)
 		if (is.function (family)) family <- family()
 		if (family$family %in% c('poisson','binomial')) {
-			p$dots$control <- NULL
+			p$args$control <- NULL
 			p$quickstart <- 0
 			return(fit.gam(p,formula))
 		}
 	}
-	if ('offset' %in% names(p$dots)) {
+	if ('offset' %in% names(p$args)) {
 		# glmmTMB issue #612
-		buildmer_offset <- p$dots$offset
-		p$dots$offset <- NULL
+		buildmer_offset <- p$args$offset
+		p$args$offset <- NULL
 		fun <- function (...) glmmTMB::glmmTMB(...,offset=buildmer_offset)
 	} else {
 		fun <- glmmTMB::glmmTMB
 	}
 	progress(p,'Fitting via glmmTMB, with ',ifelse(p$reml,'REML','ML'),': ',formula)
-	patch.lm(p,fun,c(list(formula=formula,data=p$data,family=p$family,REML=p$reml),p$dots))
+	patch.lm(p,fun,c(list(formula=formula,data=p$data,family=p$family,REML=p$reml),p$args))
 }
 
 fit.gls <- function (p,formula) {
@@ -214,32 +214,32 @@ fit.gls <- function (p,formula) {
 	if (ndrop <- sum(na)) {
 		progress(p,'gls model is rank-deficient, so dropping ',ndrop,if (ndrop > 1) ' columns/coefficients' else ' column/coefficient','. If this is the final model, the resulting summary may look a bit strange.')
 		newdata$X <- newdata$X[,!na]
-		return(patch.lm(p,nlme::gls,c(list(newform,data=newdata,method=method),p$dots)))
+		return(patch.lm(p,nlme::gls,c(list(newform,data=newdata,method=method),p$args)))
 	}
-	patch.lm(p,nlme::gls,c(list(formula,data=p$data,method=method),p$dots))
+	patch.lm(p,nlme::gls,c(list(formula,data=p$data,method=method),p$args))
 }
 
 fit.lme <- function (p,formula) {
 	fixed <- lme4::nobars(formula)
 	bars <- lme4::findbars(formula)
-	if ((length(bars) + !is.null(p$dots$random)) > 1) stop(paste0('lme can only handle a single random-effect grouping factor, yet you seem to have specified ',length(bars)))
+	if ((length(bars) + !is.null(p$args$random)) > 1) stop(paste0('lme can only handle a single random-effect grouping factor, yet you seem to have specified ',length(bars)))
 	if (!is.null(bars)) {
 		random <- mkForm(as.character(bars))
 		# and continue with lme
 	} else {
-		if (!is.null(p$dots$random)) {
-			random <- p$dots$random
-			p$dots$random <- NULL
+		if (!is.null(p$args$random)) {
+			random <- p$args$random
+			p$args$random <- NULL
 			# and continue with lme
 		} else {
-			p$dots <- p$dots[names(p$dots) %in% names(c(formals(stats::lm),formals(nlme::gls)))]
-			p$dots$control <- NULL
-			return((if (!is.null(p$dots$correlation)) fit.gls else fit.buildmer)(p,formula))
+			p$args <- p$args[names(p$args) %in% names(c(formals(stats::lm),formals(nlme::gls)))]
+			p$args$control <- NULL
+			return((if (!is.null(p$args$correlation)) fit.gls else fit.buildmer)(p,formula))
 		}
 	}
 	method <- if (p$reml) 'REML' else 'ML'
 	progress(p,'Fitting via lme, with ',method,': ',fixed,', random=',random)
-	patch.lm(p,nlme::lme,c(list(fixed,data=p$data,random=random,method=method),p$dots))
+	patch.lm(p,nlme::lme,c(list(fixed,data=p$data,random=random,method=method),p$args))
 }
 
 fit.mertree <- function (p,formula) {
@@ -250,12 +250,12 @@ fit.mertree <- function (p,formula) {
 		f <- stats::as.formula(ftext)
 		if (p$is.gaussian) {
 			progress(p,'Fitting via lmtree: ',f)
-			p$dots <- p$dots[names(p$dots) %in% names(formals(partykit::lmtree))]
-			patch.lm(p,partykit::lmtree,c(list(formula=f,data=p$data),p$dots))
+			p$args <- p$args[names(p$args) %in% names(formals(partykit::lmtree))]
+			patch.lm(p,partykit::lmtree,c(list(formula=f,data=p$data),p$args))
 		} else {
 			progress(p,'Fitting via glmtree: ',f)
-			p$dots <- p$dots[names(p$dots) %in% names(formals(partykit::glmtree))]
-			patch.lm(p,partykit::glmtree,c(list(formula=f,data=p$data,family=p$family),p$dots))
+			p$args <- p$args[names(p$args) %in% names(formals(partykit::glmtree))]
+			patch.lm(p,partykit::glmtree,c(list(formula=f,data=p$data,family=p$family),p$args))
 		}
 	} else {
 		random <- paste0('(',sapply(bars,function (x) as.character(list(x))),')',collapse=' + ')
@@ -263,15 +263,15 @@ fit.mertree <- function (p,formula) {
 		f <- stats::as.formula(ftext)
 		if (p$is.gaussian) {
 			progress(p,'Fitting via lmertree: ',f)
-			patch.mertree(p,glmertree::lmertree,c(list(formula=f,data=p$data),p$dots))
+			patch.mertree(p,glmertree::lmertree,c(list(formula=f,data=p$data),p$args))
 		} else {
 			progress(p,'Fitting via glmertree: ',f)
-			patch.mertree(p,glmertree::glmertree,c(list(formula=f,data=p$data,family=p$family),p$dots))
+			patch.mertree(p,glmertree::glmertree,c(list(formula=f,data=p$data,family=p$family),p$args))
 		}
 	}
 }
 
 fit.multinom <- function (p,formula) {
 	progress(p,'Fitting via multinom: ',formula)
-	patch.lm(p,nnet::multinom,c(list(formula=formula,data=p$data),p$dots))
+	patch.lm(p,nnet::multinom,c(list(formula=formula,data=p$data),p$args))
 }
